@@ -1,3 +1,23 @@
+/**********************************************************************
+This file is part of Exact.
+
+Copyright (c) 2022 Jo Devriendt
+
+Exact is free software: you can redistribute it and/or modify it under
+the terms of the GNU Affero General Public License version 3 as
+published by the Free Software Foundation.
+
+Exact is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+License version 3 for more details.
+
+You should have received a copy of the GNU Affero General Public
+License version 3 along with Exact. See the file used_licenses/COPYING
+or run with the flag --license=AGPLv3. If not, see
+<https://www.gnu.org/licenses/>.
+**********************************************************************/
+
 /**********************************************************************
 This file is part of the Exact program
 
@@ -13,7 +33,7 @@ See the file LICENSE or run with the flag --license=MIT.
 #include <string>
 #include <vector>
 #include "ILP.hpp"
-#include "aux.hpp"
+#include "auxiliary.hpp"
 
 class Exact {
   xct::ILP ilp;
@@ -200,4 +220,13 @@ class Exact {
    * Print Exact's internal formula.
    */
   void printFormula();
+
+  /**
+   * Under the assumptions set by setAssumptions, return implied lower and upper bound for the non-assumed variables in
+   * varnames. If no solution exists under the assumptions, return empty vector.
+   *
+   * @param varnames: variables for which to calculate the implied bounds
+   * @return: a pair of bounds for each variable in varnames
+   */
+  std::vector<std::pair<long long, long long> > propagate(const std::vector<std::string>& varnames);
 };
