@@ -1,3 +1,23 @@
+/**********************************************************************
+This file is part of Exact.
+
+Copyright (c) 2022 Jo Devriendt
+
+Exact is free software: you can redistribute it and/or modify it under
+the terms of the GNU Affero General Public License version 3 as
+published by the Free Software Foundation.
+
+Exact is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+License version 3 for more details.
+
+You should have received a copy of the GNU Affero General Public
+License version 3 along with Exact. See the file used_licenses/COPYING
+or run with the flag --license=AGPLv3. If not, see
+<https://www.gnu.org/licenses/>.
+**********************************************************************/
+
 /**********************************************************************
 This file is part of the Exact program
 
@@ -41,7 +61,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #pragma once
 
-#include "aux.hpp"
+#include "auxiliary.hpp"
 #include "quit.hpp"
 #include "used_licenses/licenses.hpp"
 
@@ -96,12 +116,15 @@ class BoolOption : public Option {
 
   void parse(const std::string& v) override {
     try {
-      val = std::stoi(v);
+      int x = std::stoi(v);
+      if (x == 0 || x == 1) {
+        val = x;
+      } else {
+        quit::exit_ERROR({"Invalid value for ", name, ": ", v, ".\nCheck usage with --help option."});
+      }
     } catch (const std::invalid_argument& ia) {
       quit::exit_ERROR({"Invalid value for ", name, ": ", v, ".\nCheck usage with --help option."});
     }
-    if (val != 0 && val != 1)
-      quit::exit_ERROR({"Invalid value for ", name, ": ", v, ".\nCheck usage with --help option."});
   }
 };
 
@@ -181,14 +204,15 @@ struct Options {
                          "Print the license text of the given license",
                          "",
                          {
+                             "AGPLv3",
+                             "Boost",
+#if WITHCOINUTILS
+                             "EPL",
+#endif
                              "MIT",
                              "RS",
-                             "Boost",
-#ifdef WITHSOPLEX
+#if WITHSOPLEX
                              "ZIB",
-#endif
-#ifdef WITHCOINUTILS
-                             "EPL",
 #endif
                          }};
   ValOption<long long> randomSeed{"seed", "Seed for the pseudo-random number generator", 1, "1 =< int",
@@ -255,8 +279,8 @@ struct Options {
       "lp-cut-maxcos",
       "Upper bound on cosine of angle between cuts added in one round, higher means cuts can be more parallel", 0.1,
       "0 =< float =< 1", [](const double& x) -> bool { return 0 <= x && x <= 1; }};
-  BoolOption slackdiv{"ca-slackdiv",
-                      "Use slack+1 as divisor for reason constraints (instead of the asserting coefficient)", false};
+  EnumOption division{
+      "ca-division", "Division method during conflict analysis", "multdiv", {"round-to-one", "slackdiv", "multdiv"}};
   BoolOption weakenNonImplying{"ca-weaken-nonimplying",
                                "Weaken non-implying falsified literals from learned constraints", true};
   BoolOption learnedMin{"ca-min", "Minimize learned constraints through generalized self-subsumption.", true};
@@ -345,7 +369,7 @@ struct Options {
       &lpLearnedCuts,
       &lpGomoryCutLimit,
       &lpMaxCutCos,
-      &slackdiv,
+      &division,
       &weakenNonImplying,
       &learnedMin,
       &bumpOnlyFalse,
@@ -406,8 +430,14 @@ struct Options {
   }
 
   void usage(const char* name) {
+    std::cout << "Welcome to Exact!\n\n";
+    std::cout << "Source code: https://gitlab.com/JoD/exact\n";
+    std::cout << "branch       " EXPANDED(GIT_BRANCH) "\n";
+    std::cout << "commit       " EXPANDED(GIT_COMMIT_HASH) "\n";
+    std::cout << "\n";
     std::cout << "Usage: " << name << " [OPTIONS] instancefile\n";
     std::cout << "or     cat instancefile | " << name << " [OPTIONS]\n";
+    std::cout << "\n";
     std::cout << "Options:\n";
     for (Option* opt : options) opt->printUsage(24);
   }
